Package: metaSeq
Type: Package
Title: Meta-analysis of RNA-Seq count data in multiple studies
Version: 1.50.0
Date: 2013-12-2
Author: Koki Tsuyuzaki, Itoshi Nikaido
Maintainer: Koki Tsuyuzaki <k.t.the-answer@hotmail.co.jp>
Depends: R (>= 2.13.0), NOISeq, snow, Rcpp
Description: The probabilities by one-sided NOISeq are combined by
        Fisher's method or Stouffer's method
License: Artistic-2.0
Packaged: 2025-10-30 04:56:46 UTC; biocbuild
biocViews: RNASeq, DifferentialExpression, Sequencing, ImmunoOncology
git_url: https://git.bioconductor.org/packages/metaSeq
git_branch: RELEASE_3_22
git_last_commit: 6be5378
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
