\name{text.busca_win}
\alias{text.busca_win}
\docType{data}
\title{
One of C++ re-implimated components in NOISeq
}
\description{
This object is imported to namespace of NOISeq in Windows machine
}
\keyword{datasets}