\name{text.n.menor_unix}
\alias{text.n.menor_unix}
\docType{data}
\title{
One of C++ re-implimated components in NOISeq
}
\description{
This object is imported to namespace of NOISeq in Unix machine
}
\keyword{datasets}